Non-documented_objects: Non-documented objects

Non-documented objectsR Documentation

Non-documented objects

Description

This page contains aliases for all "non-documented" objects that R CMD check detects in this package.

Almost all of them are generic functions that have a specific document for the corresponding method coupled to a specific class. Other functions are re-defined by setMethodS3() to default methods. Neither of these two classes are non-documented in reality.

Author(s)

Michael E. Schaffer


rtf documentation built on July 12, 2026, 5:07 p.m.